API References
==============

idinn.sourcing\_model
---------------------

.. automodule:: idinn.sourcing_model
   :members:
   :undoc-members:
   :show-inheritance:

idinn.single_controller
----------------

.. automodule:: idinn.single_controller
   :members:
   :undoc-members:
   :show-inheritance:

idinn.dual_controller
----------------

.. automodule:: idinn.dual_controller
   :members:
   :undoc-members:
   :show-inheritance:

idinn.demand
----------------

.. automodule:: idinn.demand
   :members:
   :undoc-members:
   :show-inheritance: